@@ -24,7 +24,7 @@ GOOGLENEWS_TF = "%m/%d/%Y"
 TWITTER_TF = "%Y-%m-%dT%H:%M:%SZ"
 
 NEWSAPI_URL = "https://newsapi.org/v2/everything?"
-TWITTER_URL = "https://api.twitter.com/1.1/tweets/search/recent"
+TWITTER_URL = "https://api.twitter.com/2/tweets/search/recent"
 
 
 class NewsAPI:
@@ -328,9 +328,9 @@ class TwitterParser:
             a dict of just the important parts (id, text, created_at)
         """
         data = {
-            "id": tweet["id_str"],
+            "id": tweet["id"],
             "created_at": tweet["created_at"],
-            "text": tweet["full_text"],
+            "text": tweet["text"],
         }
         return data
 
@@ -361,23 +361,30 @@ class TwitterParser:
         """
         # define params
         params = {
-            "q": topic,
-            "tweet_mode": "extended",
-            "lang": "en",
-            "count": "100",
             "start_time": start_time,
             "end_time": end_time,
+            "query": f"({topic}) (lang:en)",
+            "max_results": "100",
+            "tweet.fields": "created_at,lang",
         }
         response = requests.get(
-            "https://api.twitter.com/1.1/search/tweets.json?",
+            TWITTER_URL,
             params=params,
             headers={"authorization": "Bearer " + self.bearer_token},
         )
         tweets = pd.DataFrame()
         if response.status_code == 200:
-            for tweet in response.json()["statuses"]:
-                row = self.parse_tweet(tweet)
-                tweets = tweets.append(row, ignore_index=True)
+            for tweet in tqdm(
+                response.json()["data"],
+                leave=False,
+                desc=f"{topic} tweets",
+                dynamic_ncols=True,
+            ):
+                try:
+                    row = self.parse_tweet(tweet)
+                    tweets = tweets.append(row, ignore_index=True)
+                except Exception as e:
+                    warnings.warn(f"Error while parsing tweet ... skipping ({e})")
         else:
             warnings.warn(f"Response code {response.status_code} recieved")
 
@@ -515,7 +522,7 @@ class Elijiah:
         scores = pd.DataFrame(scores)
         return scores
 
-    def analyze_tweet_text(self, tweets: pd.DataFrame):
+    def analyze_flair_text(self, tweets: pd.DataFrame, section: str):
         """Takes a dataframe of tweets and analyzes and saves the score for each row
         ...
 
@@ -523,6 +530,8 @@ class Elijiah:
         ----------
         tweet_frame: pd.DataFrame
             dataframe containg section
+        section: pd.DataFrame
+            section of tweet_frame
 
         Returns
         -------
@@ -532,22 +541,22 @@ class Elijiah:
         # we will append probability and sentiment preds later
         probs = []
         sentiments = []
-
-        # use regex expressions (in clean function) to clean tweets
-        tweets["text"] = tweets["text"].apply(self.normalize_text)
-
-        for tweet in tweets["text"].to_list():
+        newframe = tweets.copy()
+        newframe[section] = newframe[section].apply(self.normalize_text)
+        for tweet in tqdm(
+            newframe[section].to_list(), desc=section, leave=False, dynamic_ncols=True
+        ):
             # make prediction
             sentence = flair.data.Sentence(tweet)
             self.sunflair.predict(sentence)
             # extract sentiment prediction
             probs.append(sentence.labels[0].score)  # numerical score 0-1
             sentiments.append(sentence.labels[0].value)  # 'POSITIVE' or 'NEGATIVE'
-
         # add probability and sentiment predictions to tweets dataframe
-        tweets["probability"] = probs
-        tweets["sentiment"] = sentiments
-        return tweets
+        newframe["probability"] = probs
+        newframe["sentiment"] = sentiments
+
+        return newframe
 
 
 class Isaiah:
@@ -593,8 +602,7 @@ class Isaiah:
         news_source="google",
         newsapi_key=None,
         bearer_token=None,
-        splitting=False,
-        weights={"title": 0.2, "desc": 0.3, "text": 0.5},
+        weights={"title": 0.33, "desc": 0.33, "text": 0.34},
         loud=False,
     ) -> None:
         """
@@ -608,7 +616,7 @@ class Isaiah:
             bearer token for the twitter api
         spliting : bool = False
             recursively analyze each sentence or not
-        weights : dict = {"title": 0.2, "desc": 0.3, "text": 0.5}
+        weights : dict = {"title": 0.33, "desc": 0.33, "text": 0.34}
             how to weight the title, desc, and text attributes
         loud : dict = False
             print unnecessary output (for debugging ususally)
@@ -627,7 +635,6 @@ class Isaiah:
         else:
             self.news_source = "google"
             self.newsparser = GoogleNewsParser()
-        self.splitting = splitting  # does sia.analyze use recursion to split?
         self.weights = weights
         self.loud = loud
         self.bearer_token = bearer_token
@@ -669,157 +676,7 @@ class Isaiah:
             )
         return topic_results
 
-    def compute_total_avg(self, results_df: pd.DataFrame, meta: dict):
-        """Computes avg scores for each row and then column of an entire dataframe
-
-        Parameters
-        ----------
-        results_df: pd.DataFrame
-            dataframe of results with columns ['title', 'author', 'source',
-                            'desc', 'text', 'datetime', 'url', 'urlToImage']
-        meta: dict
-            any additional information to return with the scores.
-            usually {"window": window, "up_to": up_to}
-
-        Returns
-        -------
-        returned_dict : dict
-            a dict of the avg scores and meta information
-            ex:
-            {
-                'avg': -0.06751676,
-                'desc_avg': -0.07466768,
-                'info': {
-                    'news_source': 'newsapi',
-                    'splitting': True,
-                    'up_to': '2021-4-20',
-                    'weights': {'desc': 0.3, 'text': 0.5, 'title': 0.2},
-                    'window': 2
-                        },
-                'nice': 'negative',
-                'text_avg': -0.04153505,
-                'title_avg': -0.12174464
-            }
-
-        """
-        title_avg = round(
-            self.sia.analyze_news_text(
-                results_df, "title", recursive=self.splitting
-            ).compound.mean(),
-            8,
-        )
-        desc_avg = round(
-            self.sia.analyze_news_text(
-                results_df, "desc", recursive=self.splitting
-            ).compound.mean(),
-            8,
-        )
-        text_avg = round(
-            self.sia.analyze_news_text(
-                results_df, "text", recursive=self.splitting
-            ).compound.mean(),
-            8,
-        )
-
-        if self.weights["title"] + self.weights["text"] + self.weights["desc"] != 1:
-            wstr = f"WARNING: Sum of custom weights != 1 ({self.weights})"
-            warnings.warn(wstr)
-
-        total_avg = round(
-            title_avg * self.weights["title"]
-            + desc_avg * self.weights["desc"]
-            + text_avg * self.weights["text"],
-            8,
-        )
-        # classify
-        if total_avg >= 0.05:
-            classified = "positive"
-        elif total_avg <= -0.05:
-            classified = "negative"
-        else:
-            classified = "neutral"
-
-        if self.loud:
-            print(f"Title avg: {round(title_avg*100,2)}% (compound={title_avg:.8f})")
-            print(f"Desc avg: {round(desc_avg*100,2)}% (compound={desc_avg:.8f})")
-            print(f"Text avg: {round(text_avg*100,2)}% (compound={text_avg:.8f})")
-            print(
-                f"[Total avg: {round(total_avg*100,2)}% (compound={total_avg:.8f}) <{classified}>]"
-            )
-
-        meta["weights"] = self.weights
-        meta["news_source"] = self.news_source
-        meta["splitting"] = self.splitting
-
-        returned_dict = {
-            "avg": total_avg,
-            "title_avg": title_avg,
-            "desc_avg": desc_avg,
-            "text_avg": text_avg,
-            "info": meta,
-            "nice": classified,
-        }
-        return returned_dict
-
-    def score_all(self, topic_results: dict, meta: dict):
-        """Takes care of scoring the entire dataframe for each topic
-
-        Paramaters
-        ----------
-        topic_results: dict
-            in format {topic: <pd.DataFrame>, topic: <pd.DataFrame>, ... } with
-            dataframe being of the results with columns ['title', 'author',
-                'source', 'desc', 'text', 'datetime', 'url', 'urlToImage']
-            ex:
-            {
-                'coinbase': <pd.DataFrame>,
-                'bitcoin': <pd.DataFrame>,
-                ...
-            }
-        meta: dict
-            any additional information to return with the scores.
-            usually {"window": window, "up_to": up_to}
-
-        Returns
-        -------
-        scores : dict
-            a dict of dicts arranged as {topic: scores}
-            ex:
-            {
-            'amd': {'avg': 0.2880456,
-                    'desc_avg': 0.31842738,
-                    'info': {
-                        'news_source': 'newsapi',
-                        'splitting': True,
-                        'up_to': '2021-4-20',
-                        'weights': {'desc': 0.3, 'text': 0.5, 'title': 0.2},
-                        'window': 2
-                            },
-                    'nice': 'positive',
-                    'text_avg': 0.2613019,
-                    'title_avg': 0.3093322},
-            'tesla': {'avg': -0.06751676,
-                    'desc_avg': -0.07466768,
-                    'info': {
-                        'news_source': 'newsapi',
-                        'splitting': True,
-                        'up_to': '2021-4-20',
-                        'weights': {'desc': 0.3, 'text': 0.5, 'title': 0.2},
-                        'window': 2
-                            },
-                    'nice': 'negative',
-                    'text_avg': -0.04153505,
-                    'title_avg': -0.12174464},
-            }
-
-        """
-        scores = {}
-        for topic in topic_results:
-            classification = self.compute_total_avg(topic_results[topic], meta=meta)
-            scores[topic] = classification
-        return scores
-
-    def news_sentiment_summary(
+    def news_summary(
         self,
         topics: list,
         window: int = 2,
@@ -839,10 +696,97 @@ class Isaiah:
         Returns
         -------
         scores : dict
-            a dict of dicts arranged as {topic: scores} (see score_all for a sample return)
+            a dict of dicts arranged as {topic: scores},
+            where scores is a tuple (positive count, negative cound)
         """
-        articles = self.get_articles(topics, window=window, up_to=up_to)
-        scores = self.score_all(articles, meta={"window": window, "up_to": up_to})
+        scores = {}
+        raws = self.news_sentiment(topics, window=window, up_to=up_to)
+        for topic in raws:
+            title = (
+                raws[topic]["title"]
+                .loc[raws[topic]["title"]["sentiment"] == "POSITIVE"]
+                .dropna()
+                .shape[0],
+                raws[topic]["title"]
+                .loc[raws[topic]["title"]["sentiment"] == "NEGATIVE"]
+                .dropna()
+                .shape[0],
+            )
+            desc = (
+                raws[topic]["desc"]
+                .loc[raws[topic]["desc"]["sentiment"] == "POSITIVE"]
+                .dropna()
+                .shape[0],
+                raws[topic]["desc"]
+                .loc[raws[topic]["desc"]["sentiment"] == "NEGATIVE"]
+                .dropna()
+                .shape[0],
+            )
+            text = (
+                raws[topic]["text"]
+                .loc[raws[topic]["text"]["sentiment"] == "POSITIVE"]
+                .dropna()
+                .shape[0],
+                raws[topic]["text"]
+                .loc[raws[topic]["text"]["sentiment"] == "NEGATIVE"]
+                .dropna()
+                .shape[0],
+            )
+
+            # apply weights here
+            total = (
+                round(
+                    title[0] * self.weights["title"]
+                    + desc[0] * self.weights["desc"]
+                    + text[0] * self.weights["text"],
+                    1,
+                ),
+                round(
+                    title[1] * self.weights["title"]
+                    + desc[1] * self.weights["desc"]
+                    + text[1] * self.weights["text"],
+                    1,
+                ),
+            )
+            scores[topic] = total
+        return scores
+
+    def twitter_summary(
+        self,
+        topics: list,
+        start_time=(datetime.now() - timedelta(2)).strftime(TWITTER_TF),
+        end_time=datetime.now().strftime(TWITTER_TF),
+    ):
+        """Gets the summary sentiment for each topic from twitter
+
+        Parameters
+        ----------
+        topics : list
+            list of terms to search for
+        start_time : str = (datetime.now() - timedelta(2)).strftime(TWITTER_TF)
+            how far back to search from in time format %Y-%m-%dT%H:%M:%SZ'
+        end_time : str = datetime.now().strftime(TWITTER_TF)
+            how recent to search from in time format %Y-%m-%dT%H:%M:%SZ'
+
+        Returns
+        -------
+        scores : dict
+            a dict of dicts arranged as {topic: scores},
+            where scores is a tuple (positive count, negative cound)
+        """
+        scores = {}
+        raws = self.twitter_sentiment(topics, start_time=start_time, end_time=end_time)
+        for topic in raws:
+            scores[topic] = (
+                raws[topic]
+                .loc[raws[topic]["sentiment"] == "POSITIVE"]
+                .dropna()
+                .shape[0],
+                raws[topic]
+                .loc[raws[topic]["sentiment"] == "NEGATIVE"]
+                .dropna()
+                .shape[0],
+            )
         return scores
 
     def news_sentiment(
@@ -875,17 +819,16 @@ class Isaiah:
         """
 
         articles = self.get_articles(topics, window=window, up_to=up_to)
-
         scores = {}
         for topic in articles:
-            titles = self.sia.analyze_news_text(
-                articles[topic], "title", recursive=self.splitting
+            titles = self.sia.analyze_flair_text(
+                articles[topic][["title", "datetime"]], "title"
             )
-            desc = self.sia.analyze_news_text(
-                articles[topic], "desc", recursive=self.splitting
+            desc = self.sia.analyze_flair_text(
+                articles[topic][["desc", "datetime"]], "desc"
             )
-            text = self.sia.analyze_news_text(
-                articles[topic], "text", recursive=self.splitting
+            text = self.sia.analyze_flair_text(
+                articles[topic][["text", "datetime"]], "text"
             )
             scores[topic] = {"title": titles, "desc": desc, "text": text}
         return scores
@@ -902,6 +845,10 @@ class Isaiah:
         ----------
         topics : list
             list of terms to search for
+        start_time : str = (datetime.now() - timedelta(2)).strftime(TWITTER_TF)
+            how far back to search from in time format %Y-%m-%dT%H:%M:%SZ'
+        end_time : str = datetime.now().strftime(TWITTER_TF)
+            how recent to search from in time format %Y-%m-%dT%H:%M:%SZ'
 
         Returns
         -------
@@ -918,19 +865,10 @@ class Isaiah:
             tweets = twitterparser.get_tweets(
                 topic, start_time=start_time, end_time=end_time
             )
-            scored_frame = self.sia.analyze_tweet_text(tweets)
+            scored_frame = self.sia.analyze_flair_text(tweets, "text")
             scores[topic] = scored_frame
         return scores
 
-    def twitter_sentiment_summary(
-        self,
-        topics: list,
-        start_time=(datetime.now() - timedelta(2)).strftime(TWITTER_TF),
-        end_time=datetime.now().strftime(TWITTER_TF),
-    ):
-        # not yet implemented
-        pass
-
 
 if __name__ == "__main__":
     darthvader = Isaiah(
